@@ -6,8 +6,12 @@
 # $Id: wfs.py 503 2006-02-01 17:09:12Z dokai $
 # =============================================================================
 
+import itertools
+import logging
+
 from owslib import util
 
+from io import BytesIO
 from urllib.parse import urlencode
 from owslib.util import (
     testXMLValue,
@@ -27,10 +31,17 @@ from owslib.feature.schema import get_schema
 from owslib.feature.common import (
     WFSCapabilitiesReader,
     AbstractContentMetadata,
-    makeStringIO,
 )
 
-import pyproj
+LOGGER = logging.getLogger(__name__)
+
+has_pyproj = False
+
+try:
+    import pyproj
+    has_pyproj = True
+except ImportError:
+    LOGGER.warning('pyproj not installed')
 
 n = Namespaces()
 WFS_NAMESPACE = n.get_namespace("wfs")
@@ -140,7 +151,7 @@ class WebFeatureService_1_0_0(object):
         if xml:
             self._capabilities = reader.readString(xml)
         else:
-            self._capabilities = reader.read(self.url)
+            self._capabilities = reader.read(self.url, self.timeout)
         self._buildMetadata(parse_remote_metadata)
 
     def _buildMetadata(self, parse_remote_metadata=False):
@@ -308,16 +319,15 @@ class WebFeatureService_1_0_0(object):
                 tree = etree.fromstring(data)
             except BaseException:
                 # Not XML
-                return makeStringIO(data)
+                return BytesIO(data)
             else:
                 if tree.tag == "{%s}ServiceExceptionReport" % OGC_NAMESPACE:
                     se = tree.find(nspath("ServiceException", OGC_NAMESPACE))
                     raise ServiceException(str(se.text).strip())
-                else:
-                    return makeStringIO(data)
+                return BytesIO(data)
         else:
             if have_read:
-                return makeStringIO(data)
+                return BytesIO(data)
             return u
 
     def getOperationByName(self, name):
@@ -394,16 +404,13 @@ class ContentMetadata(AbstractContentMetadata):
         # transform wgs84 bbox from given default bboxt
         self.boundingBoxWGS84 = None
 
-        if b is not None and srs is not None:
-            wgs84 = pyproj.Proj(init="epsg:4326")
+        if has_pyproj and b is not None and srs is not None:
+            wgs84 = pyproj.CRS.from_epsg(4326)
             try:
-                src_srs = pyproj.Proj(init=srs.text)
-                mincorner = pyproj.transform(
-                    src_srs, wgs84, b.attrib["minx"], b.attrib["miny"]
-                )
-                maxcorner = pyproj.transform(
-                    src_srs, wgs84, b.attrib["maxx"], b.attrib["maxy"]
-                )
+                src_srs = pyproj.CRS.from_string(srs.text)
+                transformer = pyproj.Transformer.from_crs(src_srs, wgs84, always_xy=True)
+                mincorner = transformer.transform(b.attrib["minx"], b.attrib["miny"])
+                maxcorner = transformer.transform(b.attrib["maxx"], b.attrib["maxy"])
 
                 self.boundingBoxWGS84 = (
                     mincorner[0],
@@ -413,17 +420,14 @@ class ContentMetadata(AbstractContentMetadata):
                 )
             except RuntimeError:
                 pass
-
         # crs options
         self.crsOptions = [Crs(srs.text) for srs in elem.findall(nspath("SRS"))]
 
         # verbs
-        self.verbOptions = [op.tag for op in parent.findall(nspath("Operations/*"))]
-        self.verbOptions + [
-            op.tag
-            for op in elem.findall(nspath("Operations/*"))
-            if op.tag not in self.verbOptions
-        ]
+        ops = itertools.chain(
+            parent.findall(nspath("Operations/*")), elem.findall(nspath("Operations/*"))
+        )
+        self.verbOptions = list({op.tag for op in ops})
 
         # others not used but needed for iContentMetadata harmonisation
         self.styles = None
