@@ -1,14 +1,9 @@
-from __future__ import (absolute_import, division, print_function)
-
 import logging
 import os
 import sys
 import requests
 from owslib.etree import etree, ElementType
-try:                    # Python 3
-    from urllib.parse import urlparse
-except ImportError:     # Python 2
-    from urlparse import urlparse
+from urllib.parse import urlparse
 
 
 def setup_logging(loglevel='INFO'):
@@ -88,7 +83,7 @@ def sorted_url_query(url):
 
 def service_ok(url, timeout=5):
     try:
-        resp = requests.get(url, timeout=timeout)
+        resp = requests.head(url, allow_redirects=True, timeout=timeout)
         if 'html' in resp.headers['content-type']:
             ok = False
         else:
